@@ -1,5 +1,5 @@
 package Text::MagicTemplate::Utilities;
-$VERSION = 2.11;
+$VERSION = 2.2;
 use Exporter ();
 push @ISA, qw( Exporter );
 @EXPORT_OK =  qw( parse );
@@ -12,9 +12,9 @@ sub parse
 {
     my ($s, $content, $ref) = @_;
     my $output = "IDENTIFIERS LIST";
-    $output .= _extract( $s, $content );
+    $output .= _extract( $s, $$content );
     $output .=  ': ';
-    $output;
+    \$output;
 }
 
 sub _extract
@@ -52,7 +52,7 @@ Text::MagicTemplate::Utilities - method redefinitions for Text::MagicTemplate
 
 Text::MagicTemplate::Utilities is a module that implements some method redefinition internally used by Text::MagicTemplate and its subclasses. It is not intended to be used directly.
 
-Please, refer to the documentation of Text::MagicTemplate.
+Please, refer to the documentation of L<Text::MagicTemplate>.
 
 =head1 AUTHOR
 
@@ -66,4 +66,6 @@ This software may not be modified without first notifying the author (this is to
 
 This code is provided on an "As Is'' basis, without warranty, expressed or implied. The author disclaims all warranties with regard to this software, including all implied warranties of merchantability and fitness, in no event shall the author, be liable for any special, indirect or consequential damages or any damages whatsoever including but not limited to loss of use, data or profits. By using this software you agree to indemnify the author from any liability that might arise from it is use. Should this code prove defective, you assume the cost of any and all necessary repairs, servicing, correction and any other costs arising directly or indrectly from it is use.
 
-The copyright notice must remain fully intact at all times. Use of this software or its output, constitutes acceptance of these terms.
\ No newline at end of file
+The copyright notice must remain fully intact at all times. Use of this software or its output, constitutes acceptance of these terms.
+
+
